/*
 * oma-ds-agent
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 *   @SA_Util.h
 *   @version									0.1
 *   @brief										This file is the header file of interface for utility function in SA
 */

#ifndef SA_UTIL_H_
#define SA_UTIL_H_

#include "service-adapter/sa_define.h"

/**
 * @par Description: API to put command into GList
 * This API can be used to put structure into GList
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		GList type, first index of list
 * @param[in]		GList type, last index of list
 * @param[in]		void pointer type, structure to put in the list
 *
 * @return
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
void put_into_list(GList ** commands, GList ** commands_last, void *command);

/**
 * @par Description: API to create credential string
 * This API can be used to create credential string
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		enum type, type of authentication(AUTH_TYPE_BASIC , AUTH_TYPE_MD5...)
 * @param[in]		string type, id
 * @param[in]		string type, password
 * @param[in]		string type, nonce
 * @param[in]		unsigned int type, size of nonce
 * @param[out]		string type, credential
 *
 * @return				ERROR_INTERNAL_OK on success
 *							ERROR_INTERNAL_NO_MEMORY on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
sa_error_type_e create_cred_string(auth_type_e type, const char *user_name, const char *password, const char *nonce, unsigned int nonce_size, char **cred);

/**
 *  @brief				write xml to file(for debugging)
 *  @param[in]		string to write
 *  @param[in]		path
 */
void set_xml_to_file(char *xml, const char *path);

#endif				/* SA_UTIL_H_ */
